@@ -45,7 +45,7 @@ else:
             "https://pypistats.org/api/packages/": 21600,
             "https://img.shields.io": 30,
         },
-        headers={"User-Agent": "wasi_master/pypi_cli"},
+        headers={"User-Agent": "wasi_master/pypi_cli", "Accept": "application/json"},
     )
 
 try:
@@ -626,7 +626,8 @@ def largest_files():
     headers = {"User-Agent": "wasi_master/pypi_cli", "Accept": "application/json"}
     url = f"{base_url}/stats/"
     with console.status("Loading largest files..."):
-        response = session.get(url)
+        response = session.get(url, headers=headers)
+        print(response.text)
         data = json.loads(response.text)
     packages = data["top_packages"]
     packages = dict(sorted(packages.items(), key=lambda i: i[1]["size"], reverse=True))
@@ -718,6 +719,7 @@ def releases(
         help="The name of package to show releases for, this can "
         "also include the version with this syntax: `package_name==version`",
     ),
+    version: str = Option(None, help="The version of the package to show releases for"),
     _link: bool = Option(False, metavar="link", help="Display the links to the releases"),
 ):
     """See all the available releases for a package.
@@ -1097,14 +1099,19 @@ def read_the_docs(
     query: str = Argument(
         None, help="The query you want to read the docs for, if not passed goes to the main docs page"
     ),
+    url_only: bool = Option(True, help="Only print the url to the console instead of opening it in a browser"),
 ):
     """Search the documentation for an item of a package."""
     import webbrowser  # pylint: disable=import-outside-toplevel
 
     docs_mapping = {
-        **dict.fromkeys(["py", "python", "python3"], "https://docs.python.org/3/search.html"),
-        **dict.fromkeys(["py2", "python2"], "https://docs.python.org/2/search.html"),
-        **dict.fromkeys(["pil", "pillow"], "https://pillow.readthedocs.io/en/stable/search.html"),
+        "py": "https://docs.python.org/3/search.html",
+        "python": "https://docs.python.org/3/search.html",
+        "python3": "https://docs.python.org/3/search.html",
+        "py2": "https://docs.python.org/2/search.html",
+        "python2": "https://docs.python.org/2/search.html",
+        "pil": "https://pillow.readthedocs.io/en/stable/search.html",
+        "pillow": "https://pillow.readthedocs.io/en/stable/search.html",
         "aiohttp": "https://docs.aiohttp.org/en/stable/search.html",
         "attrs": "https://www.attrs.org/en/stable/search.html",
         "babel": "https://babel.readthedocs.io/en/latest/search.html",
@@ -1192,14 +1199,26 @@ def read_the_docs(
                 raise typer.Exit()
 
     if not query:
+        if url_only:
+            console.print(url.replace("search.html", ""), style="cyan")
+            raise typer.Exit()
         webbrowser.open(url.replace("search.html", ""))
         raise typer.Exit()
     search_page = url + "?q=" + quote(query)
+    if url_only:
+        console.print(search_page, style="cyan")
+        raise typer.Exit()
     webbrowser.open(search_page)
 
 
 @app.command()
-def browse(package_name: str = Argument(..., help="The name of the package to show links for")):
+def browse(
+    package_name: str = Argument(..., help="The name of the package to show links for"),
+    url_only: bool = Option(
+        False,
+        help="If this is set then it will only show the urls instead of interactively opening them in the browser",
+    ),
+):
     """Browse for a package's URLs"""
     import webbrowser  # pylint: disable=import-outside-toplevel
 
@@ -1227,6 +1246,10 @@ def browse(package_name: str = Argument(..., help="The name of the package to sh
     urls["Release URL"] = info.get("release_url")
     urls["Mail to"] = ("mailto:" + info["maintainer_email"]) if info.get("maintainer_email") else None
 
+    if url_only:
+        console.print("\n".join(f"[red]{name:15}[/] [grey46]-[/] [cyan]{url}[/]" for name, url in urls.items() if url))
+        raise typer.Exit()
+
     answer = questionary.select(
         "Which link do you want to to open?",
         choices=[
